@@ -1,3 +1,5 @@
+no strict; no warnings;
+
 package Text::Tabs;
 
 require Exporter;
@@ -6,7 +8,7 @@ require Exporter;
 @EXPORT = qw(expand unexpand $tabstop);
 
 use vars qw($VERSION $SUBVERSION $tabstop $debug);
-$VERSION = 2013.0523;
+$VERSION = '2021.0717';
 $SUBVERSION = 'old';
 
 use strict;
